@@ -1,4 +1,4 @@
-// $Id: repeat-button.h,v 1.1 2000/10/24 16:13:56 cactus Exp $ -*- c++ -*-
+// $Id: repeat-button.h,v 1.2 2001/11/06 17:45:39 cactus Exp $ -*- c++ -*-
 
 // RadioActive Copyright (C) 1999-2000 RDI Gerg <cactus@cactus.rulez.org>
 // 
@@ -16,18 +16,21 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 //
-// $Id: repeat-button.h,v 1.1 2000/10/24 16:13:56 cactus Exp $ -*- c++ -*-
+// $Id: repeat-button.h,v 1.2 2001/11/06 17:45:39 cactus Exp $ -*- c++ -*-
 
 #ifndef RADIOACTIVE_repeat_button
 #define RADIOACTIVE_repeat_button
 
-#include <gtk--.h>
+#include <gtk--/button.h>
 
 class RepeatButton: public Gtk::Button
 {
 public:
     RepeatButton (int time = 0);
-    RepeatButton (const string& text, int time = 0);
+    
+    RepeatButton (const std::string &text = "",
+		  int                time = 0);
+
     SigC::Signal0<void> hold;
 private:
     unsigned int button_mask;
