@@ -1,4 +1,4 @@
-// $Id: speedtuner.h,v 1.8 1999/12/17 23:47:10 cactus Exp $ -*- c++ -*-
+// $Id: speedtuner.h,v 1.9 2001/11/06 17:45:39 cactus Exp $ -*- c++ -*-
 
 // RadioActive Copyright (C) 1999 RDI Gerg <cactus@cactus.rulez.org>
 // 
@@ -16,15 +16,19 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-#ifndef RADIO_speedtune
-#define RADIO_speedtune
+#ifndef RADIO_speedtuner
+#define RADIO_speedtuner
 
-#include <gtk--.h>
+#include <gtk--/table.h>
+#include <gtk--/button.h>
+#include <gtk--/tooltips.h>
+
+#include <string>
 #include <vector>
 
 class SpeedTuner: public Gtk::Table
 {
-    vector<Gtk::Button*> btnProg;
+    std::vector<Gtk::Button*> btnProg;
     Gtk::Tooltips tips;
 public:
     SpeedTuner(int row, int col);
@@ -35,8 +39,8 @@ public:
     SigC::Signal1<void, int> rclicked;
     
     // Setting the tooltips
-    void set(const vector<string>& values);
-    void set(int index, const string& value);
+    void set (const std::vector<std::string> &values);
+    void set (int index, const std::string &value);
 private:
     void btnProg_clicked(int btn);
     int btnProg_mouse(GdkEventButton *e, int btn);
