@@ -1,4 +1,4 @@
-// $Id: tuner.h,v 1.8 1999/12/17 23:47:10 cactus Exp $ -*- c++ -*-
+// $Id: tuner.h,v 1.10 2001/11/06 17:45:39 cactus Exp $ -*- c++ -*-
 
 // RadioActive Copyright (C) 1999 RDI Gerg <cactus@cactus.rulez.org>
 // 
@@ -16,21 +16,23 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-#ifndef RADIO_TUNER
-#define RADIO_TUNER
+#ifndef RADIOACTIVE_TUNER_H
+#define RADIOACTIVE_TUNER_H
 
-#include "gtk--.h"
+#include <gtk--/scale.h>
+#include <gtk--/adjustment.h>
 
 class Tuner: public Gtk::HScale
 {
     Gtk::Adjustment tuner_data;
- public:
-    Tuner(float min, float max);
-    SigC::Signal1<void, float> tune;
-    SigC::Signal1<void, float> set_value;
+public:
+    Tuner (double min, double max);
+    
+    SigC::Signal1 <void, double> freq_changed;
+    void set_freq (double freq);
+    
 private:
     void tuner_changed();
-    void set_value_impl(float value);
 };
 
-#endif
+#endif /* !RADIOACTIVE_TUNER_H */
