@@ -1,4 +1,4 @@
-// $Id: volume.h,v 1.6 1999/12/17 23:47:10 cactus Exp $ -*- c++ -*-
+// $Id: volume.h,v 1.8 2001/11/06 17:45:39 cactus Exp $ -*- c++ -*-
 
 // RadioActive Copyright (C) 1999 RDI Gerg <cactus@cactus.rulez.org>
 // 
@@ -19,22 +19,27 @@
 #ifndef RADIO_volume
 #define RADIO_volume
 
-#include <gtk--.h>
+#include <gtk--/box.h>
+#include <gtk--/adjustment.h>
+#include <gtk--/togglebutton.h>
 
-class Volume: public Gtk::Table
+class Volume: public Gtk::VBox
 {
     Gtk::Adjustment vol_adj;
     Gtk::ToggleButton btn;
+
 public:
     Volume();
-    SigC::Signal1<void, bool> mute;
-    SigC::Signal1<void, int> change;
-    int get();
-    void set(int val);
-    void set_mute(bool state);
+
+    SigC::Signal1<void, bool> mute_changed;
+    SigC::Signal1<void, int> volume_changed;
+    
+    void set_volume (int val);
+    void set_mute   (bool state);
+
 private:
-    void volume_changed();
-    void mute_toggle();
+    void vol_adj_changed ();
+    void mute_toggle ();
 };
 
 #endif
