@@ -14,17 +14,19 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-//$Id: radioactive.cc,v 1.35 2000/11/01 17:10:58 cactus Exp $ -*- c++ -*-
+//$Id: radioactive.cc,v 1.38 2001/11/06 17:45:40 cactus Exp $ -*- c++ -*-
 
 #include "radioactive.h"
 
 #include "common/file.h"
 #include "common/driver.h"
+
 #include <getopt.h>
 #include <stdexcept>
+#include <iostream>
+#include <gnome--/main.h>
 
 #include "common/properties.h"
-
 #include "common/wndMain.h"
 
 using namespace SigC;
@@ -35,22 +37,25 @@ namespace cmd
     bool console = false;
 }
 
-void usage(const string& myname)
+void usage (const std::string &myname)
 {
-    char* dev_help_str_i18n = _("Radio device (default is %s)");
-    char* dev_help_str = new char(strlen(dev_help_str_i18n) +
-				  arg::devfile.length());
-    sprintf(dev_help_str, dev_help_str_i18n, arg::devfile.c_str());
+    char *dev_help_str = g_strdup_printf (_("Radio device (default is %s)"),
+					  arg::devfile.c_str ());
     
-    cerr << _("Usage:") << " " << myname << " [-f " << _("freq")
-	 << "|-m|-v] [-d " << _("devicefile") << "] [-c]" << endl << endl;
-    cerr << "-f\t" << _("Specify the initial frequency") << endl
-	 << "-d\t" << dev_help_str << endl
-	 << "-c\t" << _("Use command line-only interface (default if not under X)")
-	 << endl
-	 << "-m\t" << _("Just mute radio and exit") << endl
-	 << "-v\t" << _("Print version information and exit") << endl
-	 << endl;
+    std::cerr << _("Usage:") << " " << myname << " [-f " << _("freq")
+	      << "|-m|-v] [-d " << _("devicefile") << "] [-c]"
+	      << std::endl
+	      << std::endl;
+
+    std::cerr << "-f\t" << _("Specify the initial frequency") << std::endl
+	      << "-d\t" << dev_help_str << std::endl
+	      << "-c\t" << _("Use command line-only interface (default if not under X)")
+	      << std::endl
+	      << "-m\t" << _("Just mute radio and exit") << std::endl
+	      << "-v\t" << _("Print version information and exit") << std::endl
+	      << std::endl;
+
+    g_free (dev_help_str);
 }
 
 void parse(int argc, char **argv)
@@ -60,8 +65,9 @@ void parse(int argc, char **argv)
 	switch (c)
 	{
 	case 'v':
-	    cout << PROGNAME << " " << VERSION
-		 << " (C) 1999 ERDI Gergo <cactus@cactus.rulez.org>" << endl;
+	    std::cout << PROGNAME << " " << VERSION
+		      << " (C) 1999-2001 ERDI Gergo <cactus@cactus.rulez.org>"
+		      << std::endl;
 	    exit(0);
 	case 'f':
 	    arg::freq = atof(optarg);
@@ -76,11 +82,11 @@ void parse(int argc, char **argv)
 	    cmd::mute = true;
 	    break;
 	case 'h':
-	    usage(argv[0]);
-	    exit(0);
+	    usage (argv[0]);
+	    exit (0);
 	case '?':
-	    usage(argv[0]);
-	    exit(1);
+	    usage (argv[0]);
+	    exit (1);
 	}
 }
 
@@ -111,23 +117,23 @@ int main(int argc, char** argv)
     {
 	radio = new Radio(arg::devfile);
     }
-    catch (runtime_error e)
+    catch (std::runtime_error e)
     {
-	cerr << e.what() << endl;
-	exit(1);
+	std::cerr << e.what() << std::endl;
+	exit (1);
     }
 
     // Muting
     if (cmd::mute)
     {
-	radio->mute(true);
-	exit(0);
+	radio->set_mute (true);
+	exit (0);
     }
 	
     // Load previous values
-    radio->set(arg::freq);
-    radio->set_vol(arg::volume);
-    radio->mute(arg::mute);
+    radio->set_freq   (arg::freq);
+    radio->set_volume (arg::volume);
+    radio->set_mute   (arg::mute);
 
     // User interface
     Gnome::Main* m = 0;
@@ -136,8 +142,8 @@ int main(int argc, char** argv)
 	m = new Gnome::Main(PROGNAME, VERSION, 1, arg_dummy);
 	wndMain* w = new wndMain(*radio);
 	w->delete_event.connect(slot(&stop));
-	vector<pair<float, string> > stations =
- 	    load_button_values(arg::progbutton_col * arg::progbutton_row);
+	SpeedButtonData stations =
+	    load_button_values(arg::progbutton_col * arg::progbutton_row);
 	
 	w->set_speedtuner(stations);
 	if (arg::save_pos)
@@ -152,13 +158,13 @@ int main(int argc, char** argv)
     }
     
     // Save current values
-    arg::freq = radio->get();
-    arg::volume = radio->get_vol();
-    arg::mute = radio->get_mute();
+    arg::freq   = radio->get_freq ();
+    arg::volume = radio->get_volume ();
+    arg::mute   = radio->get_mute ();
     save_config();
 
     if (arg::mute_exit)
-	radio->mute(true);
+	radio->set_mute (true);
 
     delete radio;
     delete[] arg_dummy;
